@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.26 1999/08/27 12:37:18 gobry Exp $
+# $Id: Base.py,v 1.28 1999/09/02 12:57:31 gobry Exp $
 
 from string import *
 import re
@@ -268,7 +268,10 @@ class Entry:
 		
 		return text
 	
-		
+
+SortByKey  = 0
+SortByType = 1
+
 class DataBase:
 	"""
 	This class represents a full bibliographic database.
@@ -312,7 +315,7 @@ class DataBase:
 		key  = None
 		
 		# generate a new key
-		while not name and not self.has_key (key):
+		while (not name) or self.has_key (key):
 			name = "entry-%d" % self.__keyid
 			key = Key (self, name)
 			
@@ -387,7 +390,7 @@ class DataBase:
 		return
 
 
-	def sort (self, sortkey = None):
+	def sort (self, sortkey = SortByKey):
 
 		""" sort entries according to a given key.  If the
 		sortkey is None, sort according to the entry key """
@@ -399,10 +402,15 @@ class DataBase:
 		def collect (entry, arg):
 			sortkey, dict, none = arg
 
-			if sortkey is None:
+			if sortkey is SortByKey :
 				# sort by key
 				dict [entry.key] = entry.key
 				return
+
+			if sortkey is SortByType :
+				# sort by type name
+				dict [entry.key] = entry.type.name
+				return
 			
 			if entry.has_key (sortkey):
 				dict [entry.key] = entry [sortkey]
