@@ -12,3 +12,8 @@ Config.define ("gnomeui/default", """ Graphical description of the
 Config.define ("gnomeui/columns", """ A list of the fields displayed
                on the main screen of the interface """)
 
+
+Config.define ("gnomeui/tooltips", """ A boolean indicating if
+               tooltips are enabled """)
+
+Config.set ("gnomeui/tooltips", 1)
