@@ -17,12 +17,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Entry.py,v 1.7 1999/08/25 11:07:35 gobry Exp $
+# $Id: Entry.py,v 1.8 1999/09/02 12:57:39 gobry Exp $
 
 from Pyblio.Base import *
 import string, re
 from gnome.ui import *
 from gtk import *
+import GTK
 
 from Pyblio import Fields, Config, Base, Types
 
@@ -99,7 +100,7 @@ class NativeEditor (GtkDialog):
             return
 
         # get the text corresponding to the entry
-        self.modified = str (self.entry.entry [self.entry.field])
+        self.modified = self.entry.entry [self.entry.field]
 
         # reset the old version (we are not supposed to set it now)
         if self.original is not None:
@@ -153,6 +154,9 @@ class BasicEditor (GtkHBox):
             self.button.add (icon)
             self.button.connect ("clicked", self.edit_native)
         
+            Utils.tooltips.set_tip (self.button,
+                                    "Edit the field in its Native format")
+        
             self.pack_end (self.button, FALSE, FALSE)
             
         self.show_all ()
@@ -291,6 +295,8 @@ class AuthorEditor (BasicEditor):
 
     def fill (self, text = None):
         def str_auth (auth):
+            if auth.last is None: return ''
+            
             if auth.first:
                 ret = auth.last + ', ' + auth.first
             else:
@@ -319,7 +325,7 @@ class AuthorEditor (BasicEditor):
             line = string.strip (line)
             if line == '': continue
             
-            autg.append (Fields.Author (line))
+            autg.append (Fields.Author (line, strict = 1))
 
         if len (autg) == 0: return None
         return autg
@@ -430,12 +436,13 @@ class FieldGroup:
 class Entry (GtkVBox):
     """ Entry displayer """
     
-    def __init__ (self, entry, properties):
+    def __init__ (self, entry, properties, acc):
         GtkVBox.__init__ (self, FALSE)
-        
-        self.entry      = entry
-        self.properties = properties
-        self.changed    = 0
+
+        self.entry       = entry
+        self.properties  = properties
+        self.changed     = 0
+        self.accelerator = acc
         
         ent = entry.type
 
@@ -489,6 +496,8 @@ class Entry (GtkVBox):
             
             self.crossref = GtkEntry ()
             self.crossref.set_editable (FALSE)
+            Utils.tooltips.set_tip (self.crossref,
+                                    "Drag an Entry to define a Cross-Reference")
             
             box.pack_start (self.crossref)
 
@@ -496,6 +505,9 @@ class Entry (GtkVBox):
             button.add (GnomeStock (STOCK_BUTTON_CANCEL))
             button.connect ("clicked", self.remove_crossref)
             
+            Utils.tooltips.set_tip (button,
+                                    "Remove the current Cross-Reference")
+            
             box.pack_start (button, fill = FALSE, expand = FALSE)
             
             self.pack_start (box, fill=FALSE, expand=FALSE)
@@ -509,7 +521,8 @@ class Entry (GtkVBox):
             self.crossref.connect ('drag_data_received', self.dnd_drag_data_received)
             self.crossref.drag_dest_set(DEST_DEFAULT_ALL, targets, GDK.ACTION_COPY)
 
-
+            box.show_all ()
+            
         if self.has_property ('has_extra'):
             # extra field addition
             hbox   = GtkHBox (FALSE, 5)
@@ -521,12 +534,27 @@ class Entry (GtkVBox):
             self.pack_start (hbox, fill=FALSE, expand=FALSE)
 
             add_button.connect ("clicked", self.extra_field, select)
-
+            hbox.show_all ()
             
+        # an invisible button
+        button = GtkButton ()
+        button.hide ()
+        button.set_usize (0,0)
+        self.pack_start (button)
+        button.connect ("clicked", self.next_entry)
+        button.add_accelerator ("clicked", self.accelerator,
+                                GDK.Escape, 0, 0)
+
         self.create_notebook (ent)
         return
 
-
+    def next_entry (self, * arg):
+        n = self.notebook
+        box = n.get_nth_page (n.get_current_page ())
+        
+        box.focus (GTK.DIR_DOWN)
+        return
+    
     def dnd_drag_data_received (self, w, context, x, y, data, info, time):
         self.crossref.set_text (data.data)
         return
@@ -606,7 +634,7 @@ class Entry (GtkVBox):
         table = self.extra.as_table ()
         self.notebook.append_page (table, GtkLabel ("Extra"))
 
-        self.notebook.show ()
+        self.notebook.show_all ()
         self.pack_start (self.notebook)
         return
 
@@ -652,19 +680,24 @@ class EntryDialog (GtkDialog):
         self.callback = callback
         self.user     = user
 
-        self.entry = Entry (entry, database.properties)
+        acc = GtkAccelGroup ()
+        self.add_accel_group (acc)
+
+        self.entry = Entry (entry, database.properties, acc)
         
         apply_b = GnomeStockButton (STOCK_BUTTON_APPLY)
         apply_b.connect ("clicked", self.apply)
-
+        apply_b.show ()
+        
         close_b = GnomeStockButton (STOCK_BUTTON_CANCEL)
         close_b.connect ("clicked", self.close)
+        close_b.show ()
         
         self.action_area.add (apply_b)
         self.action_area.add (close_b)
 
         self.vbox.pack_start (self.entry)
-        self.entry.show_all ()
+        self.entry.show ()
         return
 
     def apply (self, widget):
@@ -686,7 +719,8 @@ class EntryDialog (GtkDialog):
         elif id != self.entry.entry.name:
             
             # check unicity
-            if not self.database.has_key (Base.Key (self.database, id)):
+            if not self.database.has_key (Base.Key (self.entry.entry.key.base, id)):
+                # only change the name, the key will follow at the next save.
                 self.entry.entry.name = id
                 changed = 1
             else:
@@ -703,8 +737,13 @@ class EntryDialog (GtkDialog):
         
         if oldcr != cr:
             changed = 1
-            self.entry.entry.crossref = self.database [Base.Key (self.database, cr)]
-            
+            try:
+                self.entry.entry.crossref = self.database [Base.Key (self.entry.entry.key.base, cr)]
+            except KeyError:
+                d = GnomeErrorDialog ("Cross-Reference `%s' is unexistant in the database" % cr)
+                d.run_and_close ()
+                return
+                
         if changed and self.callback:
             self.callback (self.entry.entry, self.user)
         
