@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Pybliographic.py,v 1.16 1999/08/27 12:37:42 gobry Exp $
+# $Id: Pybliographic.py,v 1.18 1999/09/02 12:57:39 gobry Exp $
 
 import string, os, urlparse
 
@@ -34,7 +34,7 @@ from Pyblio.GnomeUI import Utils
 from Pyblio.GnomeUI.Database import *
 from Pyblio.GnomeUI.Entry  import *
 from Pyblio.GnomeUI.Search import *
-    
+
 
 class URLFileSelection (GtkFileSelection):
     """ Extended file selection dialog, with an URL field and a type
@@ -184,7 +184,8 @@ class Pybliographic (GnomeApp):
             UIINFO_ITEM_STOCK('Search...', None, self.edit_search,
                               STOCK_MENU_SEARCH),
             UIINFO_SEPARATOR,
-            UIINFO_ITEM ('Sort by Key', None, self.sort_by_key)
+            UIINFO_ITEM ('Sort by Key', None,  self.sort_by_key),
+            UIINFO_ITEM ('Sort by Type', None, self.sort_by_type),
             ]
 
         config_menu = [
@@ -283,33 +284,55 @@ class Pybliographic (GnomeApp):
     # --------------------------------------------------
     def add_opened_file (self, file):
         
-        if self.opened_files.count (file): return
-        
-        def opener (widget, self = self, file = file):
-            self.open (file)
-
-        if len (file) > 20:
-            s = os.path.split (file)
-            shortfile = '...' + s [0] [-10:] + '/' + s [1]
+        if self.opened_files.count (file):
+            # remove the existing file from the list,
+            # so that it will be placed first next time
+            self.opened_files.remove (file)
         else:
-            shortfile = file
+            # add a new file to the menu list
+            def opener (widget, self = self, file = file):
+                self.open (file)
+                return
             
-        self.insert_menus ("File/<Separator>", [
-            UIINFO_ITEM (shortfile, None, opener)])
+            if len (file) > 20:
+                s = os.path.split (file)
+                shortfile = '...' + s [0] [-10:] + '/' + s [1]
+            else:
+                shortfile = file
+            
+            self.insert_menus ("File/<Separator>", [
+                UIINFO_ITEM (shortfile, None, opener)])
 
+        # add the file on top of the list
         self.opened_files.append (file)
         return
     
     # --------------------------------------------------
         
     def sort_by_key (self, *arg):
-        self.database.sort_by_key ()
+        self.database.sort_by (Base.SortByKey)
+        return
+    
+    def sort_by_type (self, *arg):
+        self.database.sort_by (Base.SortByType)
         return
     
     # --------------------------------------------------
         
     def quit (self, *arg):
         mainquit ()
+
+    # --------------------------------------------------
+    def update_status (self):
+        self.status.pop ()
+        
+        if self.modified:
+            self.status.push (" modified database `%s' [%s, %d]" %
+                              (self.filename, self.type, len (self.database.data)))
+        else:
+            self.status.push (" database `%s' [%s, %d]" % (self.filename, self.type,
+                                                          len (self.database.data)))
+        return
     
     # --------------------------------------------------
 
@@ -346,9 +369,9 @@ class Pybliographic (GnomeApp):
         self.filename = file
         self.type     = type
         
-        self.status.pop ()
-        self.status.push ("Database `%s' [%s]" % (self.filename, self.type))
-
+        self.modified = 0
+        self.update_status ()
+        
         self.add_opened_file (file)
         return
     
@@ -380,13 +403,11 @@ class Pybliographic (GnomeApp):
             Utils.error_dialog ('Open Error', err)
             return
 
-        self.status.pop ()
-        
         self.filename = file
         self.type     = self.database.data.id
-        
-        self.status.push ("Database `%s' [%s, %d entries]"
-                   % (self.filename, self.type, len (self.database.data.keys ())))
+
+        self.modified = 0
+        self.update_status ()
 
         self.add_opened_file (file)
         return
@@ -433,13 +454,13 @@ class Pybliographic (GnomeApp):
         
         try:
             self.database.data.update ()
-            self.status.pop ()
-            self.status.push ("Database saved")
             self.modified = 0
             
         except IOError, err:
             d = GnomeErrorDialog ("can't save file: %s" % str (err))
             d.run_and_close ()
+
+        self.update_status ()
         return
     
     # --------------------------------------------------
@@ -526,16 +547,16 @@ class Pybliographic (GnomeApp):
         entry = self.database.data.new_entry ()
         
         def callback (entry, self, selection = row):
-            self.status.pop ()
-            self.status.push ("...modified...")
             self.modified = 1
             
             self.database.data [entry.key] = entry
             self.database.insert (selection, entry)
+
+            self.update_status ()
             return
         
         dialog = EntryDialog (entry, self.database.data, callback, self)
-        dialog.show_all ()
+        dialog.show ()
         pass
 
     # --------------------------------------------------
@@ -554,16 +575,16 @@ class Pybliographic (GnomeApp):
         e = selection [0]
         
         def callback (entry, self, selection = row):
-            self.status.pop ()
-            self.status.push ("...modified...")
             self.modified = 1
             
             self.database.select_row (selection, 0)
             self.database.set_row (selection, entry)
+
+            self.update_status ()
             return
         
         dialog = EntryDialog (e, self.database.data, callback, self)
-        dialog.show_all ()
+        dialog.show ()
 
     # --------------------------------------------------
 
@@ -589,9 +610,9 @@ class Pybliographic (GnomeApp):
         if self.__ans:
             self.database.remove (entry.key)
             self.modified = 1
+
+            self.update_status ()
             
-            self.status.pop ()
-            self.status.push ("...modified...")
         return
     
         
