@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: recodemodule.c,v 1.5 1999/08/25 11:07:38 gobry Exp $
+ $Id: recodemodule.c,v 1.7 1999/09/02 12:57:43 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -62,22 +62,52 @@ char * program_name = "pyrecode";
 #endif
 
 
-static void
-py_delete_recoder (void * recoder) {
-#ifdef USE_RECODE
-    RECODE_REQUEST request = (RECODE_REQUEST) recoder;
+typedef struct {
+  PyObject_HEAD
+  RECODE_REQUEST obj;
+} PyRecodeRequest_Object;
 
-    recode_delete_request (request);
+/* Destructor of BibtexFile */
+static void py_delete_recoder (PyRecodeRequest_Object * self) {
+#ifdef USE_RECODE
+    recode_delete_request (self->obj);
 #endif
+    PyMem_DEL (self);
 }
 
+static char PyRecodeRequest_Type__doc__[]  = "This is the type of a recoder";
+
+static PyTypeObject PyRecodeRequest_Type = {
+  PyObject_HEAD_INIT(&PyType_Type)
+  0,                              /*ob_size*/
+  "RecodeRequest",                 /*tp_name*/
+  sizeof(PyRecodeRequest_Object), /*tp_basicsize*/
+  0,                              /*tp_itemsize*/
+  (destructor)py_delete_recoder,  /*tp_dealloc*/
+  (printfunc)0,                   /*tp_print*/
+  (getattrfunc)0,                 /*tp_getattr*/
+  (setattrfunc)0,                 /*tp_setattr*/
+  (cmpfunc)0,                     /*tp_compare*/
+  (reprfunc)0,                    /*tp_repr*/
+  0,                              /*tp_as_number*/
+  0,                              /*tp_as_sequence*/
+  0,                              /*tp_as_mapping*/
+  (hashfunc)0,                    /*tp_hash*/
+  (ternaryfunc)0,                 /*tp_call*/
+  (reprfunc)0,                    /*tp_str*/
+  0L,0L,0L,0L,
+  PyRecodeRequest_Type__doc__
+};
+
 static PyObject *
 py_new_recoder (PyObject * self, PyObject * args) {
 #ifdef USE_RECODE
+    PyRecodeRequest_Object * ret;
+
     char * string;
     RECODE_REQUEST request;
 
-    if (! PyArg_ParseTuple(args, "s", & string))
+    if (! PyArg_ParseTuple(args, "s:request", & string))
 	return NULL;
 
     request = recode_new_request (outer);
@@ -91,7 +121,12 @@ py_new_recoder (PyObject * self, PyObject * args) {
 	return NULL;
     }
 
-    return PyCObject_FromVoidPtr (request, py_delete_recoder);
+    /* Create a new object */
+    ret = (PyRecodeRequest_Object *) 
+	PyObject_NEW (PyRecodeRequest_Object, & PyRecodeRequest_Type);
+    ret->obj = request;
+
+    return (PyObject *) ret;
 #else
     Py_INCREF (Py_None);
     return Py_None;
@@ -104,11 +139,12 @@ py_recode (PyObject * self, PyObject * args) {
     char * string;
     RECODE_REQUEST request;
     PyObject * tmp;
+    PyRecodeRequest_Object * req_obj;
 
-    if (! PyArg_ParseTuple(args, "Os", & request, & string))
+    if (! PyArg_ParseTuple(args, "O!s:recode", & PyRecodeRequest_Type, & req_obj, & string))
 	return NULL;
 
-    request = (RECODE_REQUEST) PyCObject_AsVoidPtr ((void *) request);
+    request = req_obj->obj;
 
     string = recode_string (request, string);
     if (string == NULL) {
@@ -133,7 +169,7 @@ static PyMethodDef recodeMeth [] = {
 };
 
 
-void initrecode ()
+void init_recode ()
 {
 #ifdef USE_RECODE
     outer = recode_new_outer (false);
@@ -143,6 +179,6 @@ void initrecode ()
     fprintf (stderr, "warning: to enable it, install GNU Recode and recompile.\n");
 #endif
 
-    (void) Py_InitModule ("recode", recodeMeth);
+    (void) Py_InitModule ("_recode", recodeMeth);
 }
 
